Instalando ONLYOFFICE Workspace Community usando parâmetros adicionais do script
Introdução
O ONLYOFFICE Workspace Community é uma versão gratuita do sistema colaborativo desenvolvido para gerenciar documentos, projetos, relacionamentos com clientes e correspondência de e-mail, tudo em um só lugar.
O ONLYOFFICE Workspace Community é distribuído como um script de instalação automática para sistemas operacionais Linux com Docker instalado. O script configura contêineres Docker com todos os componentes necessários para o funcionamento correto do ONLYOFFICE Workspace Community e é fácil de executar, gerenciar e atualizar.
Depois de baixar o script de instalação do ONLYOFFICE Workspace Community, talvez você precise executá-lo com parâmetros adicionais, por exemplo, para instalar cada componente em um servidor separado. Use o seguinte comando para exibir a lista de todos os parâmetros disponíveis do script:
bash workspace-install.sh -h
Abaixo você encontra uma breve descrição e alguns exemplos de uso desses parâmetros.
Nome da imagem
| Parâmetro | Descrição |
|---|---|
-ci, --communityimage | Nome da imagem do ONLYOFFICE Community Server |
-di, --documentimage | Nome da imagem do ONLYOFFICE Docs |
-mi, --mailimage | Nome da imagem do ONLYOFFICE Mail |
-cpi, --controlpanelimage | Nome da imagem do ONLYOFFICE Control Panel |
Esses parâmetros especificam o nome da imagem a partir da qual um contêiner deve ser iniciado. A imagem especificada deve estar disponível no repositório público oficial do Docker Hub.
Exemplo
bash workspace-install.sh -ims false -di onlyoffice/documentserver -ics true -icp true
Isso executará um contêiner a partir da imagem especificada do ONLYOFFICE Docs armazenada no repositório, além de executar os contêineres do ONLYOFFICE Community Server e do ONLYOFFICE Control Panel.
Versão do componente
| Parâmetro | Descrição |
|---|---|
-cv, --communityversion | Versão do ONLYOFFICE Community Server |
-dv, --documentversion | Versão do ONLYOFFICE Docs |
-mv, --mailversion | Versão do ONLYOFFICE Mail |
-cpv, --controlpanelversion | Versão do ONLYOFFICE Control Panel |
Esses parâmetros permitem instalar uma versão específica de um componente se você não quiser usar a versão mais recente disponível no repositório. Por padrão, uma imagem com a tag latest é usada para executar o contêiner de cada componente.
Exemplo
Abra o repositório do Docker Hub no seu navegador, selecione o componente e vá para a guia Tags para ver todas as tags disponíveis. Especifique a versão que você deseja instalar para os componentes necessários:
bash workspace-install.sh -ics true -cv 8.9.0.150 -ids false -icp true -cpv 1.6.0.52 -ims true -md "yourdomain.com"
Isso instalará a versão 8.9.0.150 do ONLYOFFICE Community Server, a versão 1.6.0.52 do ONLYOFFICE Control Panel e a versão mais recente do ONLYOFFICE Mail, já que a versão dele não foi especificada explicitamente.
IP do servidor
| Parâmetro | Descrição |
|---|---|
-dip, --documentserverip | Endereço IP do ONLYOFFICE Docs |
-mip, --mailserverip | Endereço IP do ONLYOFFICE Mail |
-mdbip, --mailserverdbip | Endereço IP do banco de dados do ONLYOFFICE Mail |
Esses parâmetros podem ser usados para conectar os componentes se você os instalar em máquinas separadas.
Exemplo
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Isso instalará o ONLYOFFICE Community Server com o ONLYOFFICE Control Panel e o conectará ao ONLYOFFICE Docs instalado em outra máquina que tem o endereço IP 192.168.3.202.
Nome de domínio do ONLYOFFICE Mail
| Parâmetro | Descrição |
|---|---|
-md, --maildomain | Nome de domínio do ONLYOFFICE Mail |
Este parâmetro permite especificar um nome de domínio personalizado que será usado para o ONLYOFFICE Mail.
Exemplo
bash workspace-install.sh -md "yourdomain.com"
Isso instalará todos os componentes do ONLYOFFICE Workspace Community, incluindo o ONLYOFFICE Mail, com o nome de domínio yourdomain.com especificado.
O seu domínio que será usado para manter a correspondência deve ser válido e configurado para esta máquina (ou seja, deve ter o registro A apropriado nas configurações de DNS que aponte o nome do domínio para o endereço IP da máquina onde o ONLYOFFICE Mail está instalado).
No comando acima, o parâmetro "yourdomain.com" deve ser entendido como um domínio de serviço para o ONLYOFFICE Mail. Geralmente ele é especificado no registro MX do domínio que será usado para manter a correspondência. Em regra, "yourdomain.com" se parece com mx1.onlyoffice.com
Atualização de componentes
| Parâmetro | Descrição | Valores | Padrão |
|---|---|---|---|
-u, --update | use para atualizar os componentes existentes | true|false | false |
Este parâmetro instala as versões mais recentes dos componentes desatualizados se os componentes correspondentes instalados na sua máquina estiverem desatualizados.
Exemplo
bash workspace-install.sh -u true
Isso interromperá os contêineres que precisam de atualização, os removerá e iniciará as versões mais recentes dos componentes correspondentes do ONLYOFFICE Workspace. Os contêineres cuja versão atual corresponde à mais recente disponível não serão afetados. Os componentes ignorados durante a instalação anterior também serão ignorados. Os dados do portal serão preservados automaticamente.
Credenciais
| Parâmetro | Descrição |
|---|---|
-un, --username | nome de usuário do dockerhub |
-p, --password | senha do dockerhub |
Esses parâmetros são usados quando credenciais são fornecidas para acessar um repositório de teste, permitindo executar contêineres a partir das imagens armazenadas nele.
Exemplo
bash workspace-install.sh -md "yourdomain.com" -un username -p password
Instalação de componentes
| Parâmetro | Descrição | Valores | Padrão |
|---|---|---|---|
-ics, --installcommunityserver | instalar o ONLYOFFICE Community Server | true|false|pull | true |
-ids, --installdocumentserver | instalar o ONLYOFFICE Docs | true|false|pull | true |
-ims, --installmailserver | instalar o ONLYOFFICE Mail | true|false|pull | true |
-icp, --installcontrolpanel | instalar o ONLYOFFICE Control Panel | true|false|pull | true |
Esses parâmetros permitem especificar se um determinado componente deve ser instalado. Eles podem ser usados para instalar cada componente em um servidor separado.
- Use o valor
truepara instalar um componente. - Use o valor
falsepara ignorar a instalação de um componente. - Use o valor
pullpara baixar um componente sem instalá-lo.
Exemplo
bash workspace-install.sh -ims false
Isso instalará todos os componentes do ONLYOFFICE Workspace sem o ONLYOFFICE Mail.
bash workspace-install.sh -ics false -ids true -icp false -ims false -es true
Isso ignorará a instalação do ONLYOFFICE Mail, do ONLYOFFICE Community Server e do ONLYOFFICE Control Panel e instalará apenas o ONLYOFFICE Docs.
Tipo de instalação
| Parâmetro | Descrição | Valores | Padrão |
|---|---|---|---|
-it, --installation_type | tipo de instalação | WORKSPACE|WORKSPACE_ENTERPRISE | WORKSPACE_ENTERPRISE |
Este parâmetro instala a solução especificada: ONLYOFFICE Workspace ou ONLYOFFICE Workspace Enterprise Edition.
Exemplo
bash workspace-install.sh -it GROUPS
Isso instalará a solução ONLYOFFICE Workspace, que inclui os componentes ONLYOFFICE Community Server e ONLYOFFICE Control Panel.
Usando um componente como servidor externo
| Parâmetro | Descrição | Valores | Padrão |
|---|---|---|---|
-es, --useasexternalserver | usar como servidor externo | true|false | false |
Este parâmetro é usado ao instalar componentes em servidores separados.
- Use o valor
trueao instalar o ONLYOFFICE Docs e o ONLYOFFICE Mail em máquinas separadas. - Use o valor
falseao instalar o ONLYOFFICE Community Server junto com o ONLYOFFICE Control Panel em uma máquina separada.
Exemplo
bash workspace-install.sh -ics false -ids false -icp false -ims true -md "yourdomain.com" -es true
Isso ignorará a instalação do ONLYOFFICE Docs, do ONLYOFFICE Community Server e do ONLYOFFICE Control Panel e instalará apenas o ONLYOFFICE Mail.
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Isso instalará o ONLYOFFICE Community Server com o ONLYOFFICE Control Panel e o conectará ao ONLYOFFICE Docs instalado em outra máquina.
Criação do arquivo de swap
| Parâmetro | Descrição | Valores | Padrão |
|---|---|---|---|
-ms, --makeswap | criar arquivo de swap | true|false | false |
Este parâmetro cria um arquivo de swap de 6 GB. Por padrão, o valor true é especificado, portanto você não precisa indicar este parâmetro ao executar o script. O arquivo de swap será criado automaticamente.
Exemplo
bash workspace-install.sh -ms false
Se um arquivo de swap já existir, use este comando para impedir que um novo arquivo de swap seja criado durante a instalação.
Se você executar o script novamente sem o parâmetro -ms, ele verifica se o onlyoffice_swapfile está presente. Se o arquivo de swap já existir, o script não o criará novamente.
Servidor MySQL
| Parâmetro | Descrição | Padrão |
|---|---|---|
-mysqlh, --mysqlhost | Host do servidor MySQL | localhost |
-mysqlprt, --mysqlport | Porta do servidor MySQL | 3306 |
-mysqlru, --mysqlrootuser | Usuário root do servidor MySQL | root |
-mysqlrp, --mysqlrootpassword | Senha root do servidor MySQL | my-secret-pw |
Se você não especificar explicitamente esses parâmetros, os valores padrão serão usados.
Exemplo
bash workspace-install.sh -mysqlru root -mysqlrp new-secret-pw
Este comando define uma senha personalizada para a conta root do MySQL durante a instalação do ONLYOFFICE Workspace.
Banco de dados do ONLYOFFICE Community Server
| Parâmetro | Descrição | Padrão |
|---|---|---|
-mysqld, --mysqldatabase | Nome do banco de dados do ONLYOFFICE Community Server | onlyoffice |
-mysqlu, --mysqluser | Usuário do banco de dados do ONLYOFFICE Community Server | onlyoffice_user |
-mysqlp, --mysqlpassword | Senha do banco de dados do ONLYOFFICE Community Server | onlyoffice_pass |
Esses parâmetros permitem criar o banco de dados do ONLYOFFICE Community Server com um nome personalizado, junto com um nome de usuário e uma senha para uma conta com permissões de superusuário. Se você não especificar explicitamente esses parâmetros, os valores padrão serão usados.
Exemplo
bash workspace-install.sh -mysqld communitydatabase -mysqlu username -mysqlp password
Banco de dados do ONLYOFFICE Mail
| Parâmetro | Descrição | Padrão |
|---|---|---|
-mysqlmd, --mysqlmaildatabase | Nome do banco de dados do ONLYOFFICE Mail | onlyoffice_mailserver |
-mysqlmu, --mysqlmailuser | Usuário do banco de dados do ONLYOFFICE Mail | mail_admin |
-mysqlmp, --mysqlmailpassword | Senha do banco de dados do ONLYOFFICE Mail | Isadmin123 |
Esses parâmetros permitem criar o banco de dados do ONLYOFFICE Mail especificando um nome de banco de dados personalizado, bem como um nome de usuário e uma senha para a conta com permissões de superusuário no banco de dados criado. Se você não especificar explicitamente esses parâmetros, os valores padrão serão usados.
Exemplo
bash workspace-install.sh -md "mx.yourdomain.com" -mysqlmd maildatabase -mysqlmu username -mysqlmp password
Porta do ONLYOFFICE Community Server
| Parâmetro | Descrição | Padrão |
|---|---|---|
-cp, --communityport | Porta do ONLYOFFICE Community Server | 80 |
Este parâmetro altera a porta na qual o ONLYOFFICE Community Server é executado. A porta padrão é a 80.
Exemplo
bash workspace-install.sh -cp 8080
Configuração do core.machinekey
| Parâmetro | Descrição |
|---|---|
-mk, --machinekey | Configuração da chave core.machinekey |
Este parâmetro permite especificar uma machinekey personalizada ao instalar o ONLYOFFICE Workspace Community.
Este parâmetro é gravado no arquivo de configuração /app/onlyoffice/CommunityServer/data/.private/machinekey.
Exemplo
bash workspace-install.sh -mk yourmachinekey
Configuração do segredo JWT
| Parâmetro | Descrição |
|---|---|
-jwt, --jwtsecret | Configuração da chave secreta JWT |
Este parâmetro permite especificar uma chave secreta JWT personalizada ao instalar o ONLYOFFICE Workspace Community. A chave secreta é usada para assinar o token web JSON e validar o token na solicitação ao ONLYOFFICE Docs.
Este parâmetro é gravado nos seguintes arquivos de configuração (os caminhos são indicados dentro dos contêineres):
- Para o Community Server -
/var/www/onlyoffice/WebStudio/web.appsettings.config - Para o Document Server -
/etc/onlyoffice/documentserver/local.json
Exemplo
bash workspace-install.sh -jwt yoursecret